@@ -84,8 +84,6 @@ def dashize_line(line, length):
 
 
 class ImageDrawEx(object):
-    self_generative_methods = []
-
     def __init__(self, filename, size, **kwargs):
         if kwargs.get('im'):
             self.image = kwargs.get('im')
@@ -231,12 +229,6 @@ class ImageDrawEx(object):
             del kwargs['outline']
             self.line(xy, **kwargs)
 
-    def label(self, box, string, **kwargs):
-        lines = TextFolder(box, string, adjustBaseline=True, **kwargs)
-
-        self.rectangle(lines.outlineBox(), fill='white', outline='black')
-        self.textarea(box, string, **kwargs)
-
     def text(self, xy, string, **kwargs):
         fill = kwargs.get('fill')
         font = kwargs.get('font')
@@ -278,6 +270,11 @@ class ImageDrawEx(object):
 
     def textarea(self, box, string, **kwargs):
         lines = TextFolder(box, string, scale=self.scale_ratio, **kwargs)
+
+        if kwargs.get('outline'):
+            outline = kwargs.get('outline')
+            self.rectangle(lines.outlineBox(), fill='white', outline=outline)
+
         for string, xy in lines.each_line():
             self.text(xy, string, **kwargs)
 
