@@ -19,26 +19,26 @@ from blockdiag.utils.XY import XY
 
 
 class Actor(NodeShape):
-    def __init__(self, node, metrix=None):
-        super(Actor, self).__init__(node, metrix)
+    def __init__(self, node, metrics=None):
+        super(Actor, self).__init__(node, metrics)
 
-        self.radius = metrix.nodeHeight / 8  # radius of actor's head
-        self.center = metrix.cell(node).center()
+        self.radius = metrics.node_height / 8  # radius of actor's head
+        self.center = metrics.cell(node).center
 
         self.connectors[1] = XY(self.center.x + self.radius * 5, self.center.y)
         self.connectors[3] = XY(self.center.x - self.radius * 5, self.center.y)
 
     def head_part(self):
         r = self.radius
-        top = self.metrix.cell(self.node).top()
+        top = self.metrics.cell(self.node).top
         return (top.x - r, top.y, top.x + r, top.y + r * 2)
 
     def body_part(self):
         r = self.radius
-        m = self.metrix.cell(self.node)
+        m = self.metrics.cell(self.node)
 
-        r = self.metrix.nodeHeight / 8  # radius of actor's head
-        bodyC = m.center()
+        r = self.metrics.node_height / 8  # radius of actor's head
+        bodyC = m.center
         neckWidth = r * 2 / 3  # neck size
         arm = r * 4  # arm length
         armWidth = r
@@ -49,7 +49,7 @@ class Actor(NodeShape):
         legXin = r * 2  # toe inner position
         legYin = bodyHeight + r * 3
 
-        return [XY(bodyC.x + neckWidth, m.topCenter().y + r),
+        return [XY(bodyC.x + neckWidth, m.top.y + r),
                 XY(bodyC.x + neckWidth, bodyC.y - armWidth),  # neck end
                 XY(bodyC.x + arm, bodyC.y - armWidth),
                 XY(bodyC.x + arm, bodyC.y),  # right arm end
@@ -67,7 +67,7 @@ class Actor(NodeShape):
                 XY(bodyC.x - arm, bodyC.y),
                 XY(bodyC.x - arm, bodyC.y - armWidth),
                 XY(bodyC.x - neckWidth, bodyC.y - armWidth),  # left arm end
-                XY(bodyC.x - neckWidth, m.topCenter().y + r)]
+                XY(bodyC.x - neckWidth, m.top.y + r)]
 
     def render_shape(self, drawer, format, **kwargs):
         outline = kwargs.get('outline')
