@@ -19,14 +19,14 @@ from blockdiag.utils.XY import XY
 
 
 class BeginPoint(NodeShape):
-    def __init__(self, node, metrix=None):
-        super(BeginPoint, self).__init__(node, metrix)
+    def __init__(self, node, metrics=None):
+        super(BeginPoint, self).__init__(node, metrics)
 
-        m = metrix.cell(node)
+        m = metrics.cell(node)
 
-        self.radius = metrix.cellSize
-        self.center = m.center()
-        self.textbox = [m.top().x, m.top().y, m.right().x, m.right().y]
+        self.radius = metrics.cellsize
+        self.center = m.center
+        self.textbox = [m.top.x, m.top.y, m.right.x, m.right.y]
         self.textalign = 'left'
         self.connectors = [XY(self.center.x, self.center.y - self.radius),
                            XY(self.center.x + self.radius, self.center.y),
