@@ -20,13 +20,13 @@ from blockdiag.imagedraw.simplesvg import pathdata
 
 
 class Terminator(NodeShape):
-    def __init__(self, node, metrix=None):
-        super(Terminator, self).__init__(node, metrix)
+    def __init__(self, node, metrics=None):
+        super(Terminator, self).__init__(node, metrics)
 
-        m = self.metrix.cell(self.node)
-        r = self.metrix.cellSize * 2
-        self.textbox = (m.topLeft().x + r, m.topLeft().y,
-                        m.bottomRight().x - r, m.bottomRight().y)
+        m = self.metrics.cell(self.node)
+        r = self.metrics.cellsize * 2
+        self.textbox = (m.topleft.x + r, m.topleft.y,
+                        m.bottomright.x - r, m.bottomright.y)
 
     def render_shape(self, drawer, format, **kwargs):
         fill = kwargs.get('fill')
@@ -35,7 +35,7 @@ class Terminator(NodeShape):
         self.render_shape_background(drawer, format, **kwargs)
 
         # draw outline
-        box = self.metrix.cell(self.node).box()
+        box = self.metrics.cell(self.node).box
         if not kwargs.get('shadow') and self.node.background:
             drawer.loadImage(self.node.background, self.textbox)
 
@@ -43,10 +43,10 @@ class Terminator(NodeShape):
         outline = kwargs.get('outline')
         fill = kwargs.get('fill')
 
-        m = self.metrix.cell(self.node)
-        r = self.metrix.cellSize * 2
+        m = self.metrics.cell(self.node)
+        r = self.metrics.cellsize * 2
 
-        box = m.box()
+        box = m.box
         ellipses = [(box[0], box[1], box[0] + r * 2, box[3]),
                     (box[2] - r * 2, box[1], box[2], box[3])]
 
@@ -79,12 +79,12 @@ class Terminator(NodeShape):
         fill = kwargs.get('fill')
 
         # create pathdata
-        m = self.metrix.cell(self.node)
-        r = self.metrix.cellSize * 2
-        height = self.metrix.nodeHeight
+        m = self.metrics.cell(self.node)
+        r = self.metrics.cellsize * 2
+        height = self.metrics.node_height
 
-        box = (m.topLeft().x + r, m.topLeft().y,
-               m.bottomRight().x - r, m.bottomRight().y)
+        box = (m.topleft.x + r, m.topleft.y,
+               m.bottomright.x - r, m.bottomright.y)
         if kwargs.get('shadow'):
             box = self.shift_shadow(box)
 
