@@ -4,10 +4,10 @@ from blockdiag.noderenderer import install_renderer
 
 
 class NoneShape(NodeShape):
-    def __init__(self, node, metrix=None):
-        super(NoneShape, self).__init__(node, metrix)
+    def __init__(self, node, metrics=None):
+        super(NoneShape, self).__init__(node, metrics)
 
-        p = metrix.cell(node).center()
+        p = metrics.cell(node).center
         self.connectors = [p, p, p, p]
 
     def render_label(self, drawer, **kwargs):
