@@ -25,7 +25,7 @@ class RoundedBox(NodeShape):
         self.render_shape_background(drawer, format, **kwargs)
 
         # draw outline
-        box = self.metrix.cell(self.node).box()
+        box = self.metrics.cell(self.node).box
         if not kwargs.get('shadow'):
             if self.node.background:
                 drawer.loadImage(self.node.background, box)
@@ -36,9 +36,9 @@ class RoundedBox(NodeShape):
         outline = kwargs.get('outline')
         fill = kwargs.get('fill')
 
-        m = self.metrix.cell(self.node)
-        r = self.metrix.cellSize
-        box = m.box()
+        m = self.metrics.cell(self.node)
+        r = self.metrics.cellsize
+        box = m.box
 
         lines = [(XY(box[0] + r, box[1]), XY(box[2] - r, box[1])),
                  (XY(box[2], box[1] + r), XY(box[2], box[3] - r)),
@@ -58,10 +58,10 @@ class RoundedBox(NodeShape):
     def render_shape_background(self, drawer, format, **kwargs):
         fill = kwargs.get('fill')
 
-        m = self.metrix.cell(self.node)
-        r = self.metrix.cellSize
+        m = self.metrics.cell(self.node)
+        r = self.metrics.cellsize
 
-        box = m.box()
+        box = m.box
         ellipses = [(box[0], box[1], box[0] + r * 2, box[1] + r * 2),
                     (box[2] - r * 2, box[1], box[2], box[1] + r * 2),
                     (box[0], box[3] - r * 2, box[0] + r * 2, box[3]),
@@ -92,8 +92,8 @@ class RoundedBox(NodeShape):
         fill = kwargs.get('fill')
 
         # create pathdata
-        box = self.metrix.cell(self.node).box()
-        r = self.metrix.cellSize
+        box = self.metrics.cell(self.node).box
+        r = self.metrics.cellsize
 
         if kwargs.get('shadow'):
             box = self.shift_shadow(box)
